==> haskell-blaze-builder-0.4.2.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 blaze-builder
version:              0.4.2.1
visibility:           public
id:                   blaze-builder-0.4.2.1-KRXf5d4GbjLDdq3vlVdrGQ
key:                  blaze-builder-0.4.2.1-KRXf5d4GbjLDdq3vlVdrGQ
license:              BSD-3-Clause
copyright:
    (c) 2010-2014 Simon Meier
    (c) 2010 Jasper Van der Jeugt
    (c) 2013-2015 Leon P Smith

maintainer:           Leon Smith <leon@melding-monads.com>
author:               Jasper Van der Jeugt, Simon Meier, Leon P Smith
stability:            Experimental
homepage:             http://github.com/lpsmith/blaze-builder
synopsis:             Efficient buffered output.
description:
    This library provides an implementation of the older
    blaze-builder interface in terms of the new builder that
    shipped with bytestring-0.10.4.0

    This implementation is mostly intended as a bridge to the
    new builder,  so that code that uses the old interface
    can interoperate with code that uses the new
    implementation.   Note that no attempt has been made
    to preserve the old internal modules,  so code that
    has these dependencies cannot use this interface.

    New code should,  for the most part,  use the new
    interface.   However, this module does implement
    a chunked HTTP encoding,  which is not otherwise
    implemented (yet?) with the new builder.

category:             Data
abi:                  2850159b295d31b68dcaa961beabed96
exposed:              True
exposed-modules:
    Blaze.ByteString.Builder Blaze.ByteString.Builder.ByteString
    Blaze.ByteString.Builder.Char.Utf8 Blaze.ByteString.Builder.Char8
    Blaze.ByteString.Builder.Compat.Write Blaze.ByteString.Builder.HTTP
    Blaze.ByteString.Builder.Html.Utf8
    Blaze.ByteString.Builder.Html.Word Blaze.ByteString.Builder.Int
    Blaze.ByteString.Builder.Internal.Write
    Blaze.ByteString.Builder.Word

import-dirs:          /usr/lib/ghc-8.10.4/site-local/blaze-builder-0.4.2.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/blaze-builder-0.4.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/blaze-builder-0.4.2.1
hs-libraries:         HSblaze-builder-0.4.2.1-KRXf5d4GbjLDdq3vlVdrGQ
depends:
    base-4.14.1.0 bytestring-0.10.12.0 deepseq-1.4.4.0 text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-blaze-builder/html/blaze-builder.haddock

haddock-html:         /usr/share/doc/haskell-blaze-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-builder-0.4.2.1-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 blaze-builder
version:              0.4.2.1
visibility:           public
id:                   blaze-builder-0.4.2.1-CvyaA91rGJh3LGq34EOJVB
key:                  blaze-builder-0.4.2.1-CvyaA91rGJh3LGq34EOJVB
license:              BSD-3-Clause
copyright:
    (c) 2010-2014 Simon Meier
    (c) 2010 Jasper Van der Jeugt
    (c) 2013-2015 Leon P Smith

maintainer:           Leon Smith <leon@melding-monads.com>
author:               Jasper Van der Jeugt, Simon Meier, Leon P Smith
stability:            Experimental
homepage:             http://github.com/lpsmith/blaze-builder
synopsis:             Efficient buffered output.
description:
    This library provides an implementation of the older
    blaze-builder interface in terms of the new builder that
    shipped with bytestring-0.10.4.0

    This implementation is mostly intended as a bridge to the
    new builder,  so that code that uses the old interface
    can interoperate with code that uses the new
    implementation.   Note that no attempt has been made
    to preserve the old internal modules,  so code that
    has these dependencies cannot use this interface.

    New code should,  for the most part,  use the new
    interface.   However, this module does implement
    a chunked HTTP encoding,  which is not otherwise
    implemented (yet?) with the new builder.

category:             Data
abi:                  ae61f4c68ab3f9cddbf325313c631f2d
exposed:              True
exposed-modules:
    Blaze.ByteString.Builder Blaze.ByteString.Builder.ByteString
    Blaze.ByteString.Builder.Char.Utf8 Blaze.ByteString.Builder.Char8
    Blaze.ByteString.Builder.Compat.Write Blaze.ByteString.Builder.HTTP
    Blaze.ByteString.Builder.Html.Utf8
    Blaze.ByteString.Builder.Html.Word Blaze.ByteString.Builder.Int
    Blaze.ByteString.Builder.Internal.Write
    Blaze.ByteString.Builder.Word

import-dirs:          /usr/lib/ghc-8.10.5/site-local/blaze-builder-0.4.2.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/blaze-builder-0.4.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/blaze-builder-0.4.2.1
hs-libraries:         HSblaze-builder-0.4.2.1-CvyaA91rGJh3LGq34EOJVB
depends:
    base-4.14.2.0 bytestring-0.10.12.0 deepseq-1.4.4.0 text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-blaze-builder/html/blaze-builder.haddock

haddock-html:         /usr/share/doc/haskell-blaze-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
